/*
 * Produce a C source file that contains the Motif private error
 * messages.
 */

#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>

extern char *XME_WARNING;
extern char *_XmMsgBaseClass_0000;
extern char *_XmMsgBaseClass_0001;
extern char *_XmMsgBaseClass_0002;
extern char *_XmMsgBulletinB_0001;
extern char *_XmMsgCSText_0000;
extern char *_XmMsgCSText_0001;
extern char *_XmMsgCSText_0002;
extern char *_XmMsgCSText_0003;
extern char *_XmMsgCSText_0004;
extern char *_XmMsgCSText_0005;
extern char *_XmMsgCSText_0006;
extern char *_XmMsgCSText_0007;
extern char *_XmMsgCascadeB_0000;
extern char *_XmMsgCascadeB_0001;
extern char *_XmMsgCascadeB_0002;
extern char *_XmMsgCascadeB_0003;
extern char *_XmMsgComboBox_0000;
extern char *_XmMsgComboBox_0001;
extern char *_XmMsgComboBox_0002;
extern char *_XmMsgComboBox_0003;
extern char *_XmMsgComboBox_0004;
extern char *_XmMsgComboBox_0005;
extern char *_XmMsgComboBox_0006;
extern char *_XmMsgComboBox_0007;
extern char *_XmMsgComboBox_0008;
extern char *_XmMsgCommand_0000;
extern char *_XmMsgCommand_0001;
extern char *_XmMsgCommand_0002;
extern char *_XmMsgCommand_0003;
extern char *_XmMsgCommand_0004;
extern char *_XmMsgCommand_0005;
extern char *_XmMsgContainer_0000;
extern char *_XmMsgCutPaste_0000;
extern char *_XmMsgCutPaste_0001;
extern char *_XmMsgCutPaste_0002;
extern char *_XmMsgCutPaste_0003;
extern char *_XmMsgCutPaste_0004;
extern char *_XmMsgCutPaste_0005;
extern char *_XmMsgCutPaste_0006;
extern char *_XmMsgCutPaste_0007;
extern char *_XmMsgCutPaste_0008;
extern char *_XmMsgCutPaste_0009;
extern char *_XmMsgDialogS_0000;
extern char *_XmMsgDisplay_0001;
extern char *_XmMsgDisplay_0002;
extern char *_XmMsgDisplay_0003;
extern char *_XmMsgDragBS_0000;
extern char *_XmMsgDragBS_0001;
extern char *_XmMsgDragBS_0002;
extern char *_XmMsgDragBS_0003;
extern char *_XmMsgDragBS_0004;
extern char *_XmMsgDragBS_0005;
extern char *_XmMsgDragBS_0006;
extern char *_XmMsgDragC_0001;
extern char *_XmMsgDragC_0002;
extern char *_XmMsgDragC_0003;
extern char *_XmMsgDragC_0004;
extern char *_XmMsgDragC_0005;
extern char *_XmMsgDragC_0006;
extern char *_XmMsgDragICC_0000;
extern char *_XmMsgDragICC_0001;
extern char *_XmMsgDragIcon_0000;
extern char *_XmMsgDragIcon_0001;
extern char *_XmMsgDragIcon_0002;
extern char *_XmMsgDragOverS_0000;
extern char *_XmMsgDragOverS_0001;
extern char *_XmMsgDragOverS_0002;
extern char *_XmMsgDragOverS_0003;
extern char *_XmMsgDragUnder_0000;
extern char *_XmMsgDragUnder_0001;
extern char *_XmMsgDropSMgrI_0001;
extern char *_XmMsgDropSMgrI_0002;
extern char *_XmMsgDropSMgrI_0003;
extern char *_XmMsgDropSMgr_0001;
extern char *_XmMsgDropSMgr_0002;
extern char *_XmMsgDropSMgr_0003;
extern char *_XmMsgDropSMgr_0004;
extern char *_XmMsgDropSMgr_0005;
extern char *_XmMsgDropSMgr_0006;
extern char *_XmMsgDropSMgr_0007;
extern char *_XmMsgDropSMgr_0008;
extern char *_XmMsgDropSMgr_0009;
extern char *_XmMsgDropSMgr_0010;
extern char *_XmMsgForm_0000;
extern char *_XmMsgForm_0002;
extern char *_XmMsgForm_0003;
extern char *_XmMsgForm_0004;
extern char *_XmMsgGadget_0000;
extern char *_XmMsgGeoUtils_0000;
extern char *_XmMsgGeoUtils_0001;
extern char *_XmMsgGeoUtils_0002;
extern char *_XmMsgGetSecRes_0000;
extern char *_XmMsgGrabS_0000;
extern char *_XmMsgLabel_0003;
extern char *_XmMsgLabel_0004;
extern char *_XmMsgList_0000;
extern char *_XmMsgList_0005;
extern char *_XmMsgList_0006;
extern char *_XmMsgList_0007;
extern char *_XmMsgList_0008;
extern char *_XmMsgList_0009;
extern char *_XmMsgList_0010;
extern char *_XmMsgList_0011;
extern char *_XmMsgList_0012;
extern char *_XmMsgList_0013;
extern char *_XmMsgList_0014;
extern char *_XmMsgList_0015;
extern char *_XmMsgMainW_0000;
extern char *_XmMsgMainW_0001;
extern char *_XmMsgManager_0000;
extern char *_XmMsgManager_0001;
extern char *_XmMsgMenuShell_0000;
extern char *_XmMsgMenuShell_0001;
extern char *_XmMsgMenuShell_0002;
extern char *_XmMsgMenuShell_0003;
extern char *_XmMsgMenuShell_0004;
extern char *_XmMsgMenuShell_0005;
extern char *_XmMsgMenuShell_0006;
extern char *_XmMsgMenuShell_0007;
extern char *_XmMsgMenuShell_0008;
extern char *_XmMsgMenuShell_0009;
extern char *_XmMsgMessageB_0003;
extern char *_XmMsgMessageB_0004;
extern char *_XmMsgMotif_0000;
extern char *_XmMsgMotif_0001;
extern char *_XmMsgNavigMap_0000;
extern char *_XmMsgNotebook_0000;
extern char *_XmMsgPanedW_0000;
extern char *_XmMsgPanedW_0001;
extern char *_XmMsgPanedW_0002;
extern char *_XmMsgPanedW_0003;
extern char *_XmMsgPanedW_0004;
extern char *_XmMsgPanedW_0005;
extern char *_XmMsgPixConv_0000;
extern char *_XmMsgPrimitive_0000;
extern char *_XmMsgProtocols_0000;
extern char *_XmMsgProtocols_0001;
extern char *_XmMsgProtocols_0002;
extern char *_XmMsgRegion_0000;
extern char *_XmMsgRepType_0000;
extern char *_XmMsgRepType_0001;
extern char *_XmMsgRepType_0002;
extern char *_XmMsgResConvert_0000;
extern char *_XmMsgResConvert_0001;
extern char *_XmMsgResConvert_0002;
extern char *_XmMsgResConvert_0003;
extern char *_XmMsgResConvert_0004;
extern char *_XmMsgResConvert_0005;
extern char *_XmMsgResConvert_0006;
extern char *_XmMsgResConvert_0007;
extern char *_XmMsgResConvert_0008;
extern char *_XmMsgResConvert_0009;
extern char *_XmMsgResConvert_0010;
extern char *_XmMsgResConvert_0011;
extern char *_XmMsgResConvert_0012;
extern char *_XmMsgResConvert_0013;
extern char *_XmMsgResConvert_0014;
extern char *_XmMsgResConvert_0015;
extern char *_XmMsgResConvert_0016;
extern char *_XmMsgRowColText_0024;
extern char *_XmMsgRowColumn_0000;
extern char *_XmMsgRowColumn_0001;
extern char *_XmMsgRowColumn_0002;
extern char *_XmMsgRowColumn_0003;
extern char *_XmMsgRowColumn_0004;
extern char *_XmMsgRowColumn_0005;
extern char *_XmMsgRowColumn_0007;
extern char *_XmMsgRowColumn_0008;
extern char *_XmMsgRowColumn_0015;
extern char *_XmMsgRowColumn_0016;
extern char *_XmMsgRowColumn_0017;
extern char *_XmMsgRowColumn_0018;
extern char *_XmMsgRowColumn_0019;
extern char *_XmMsgRowColumn_0020;
extern char *_XmMsgRowColumn_0022;
extern char *_XmMsgRowColumn_0023;
extern char *_XmMsgRowColumn_0025;
extern char *_XmMsgRowColumn_0026;
extern char *_XmMsgRowColumn_0027;
extern char *_XmMsgScaleScrBar_0004;
extern char *_XmMsgScale_0000;
extern char *_XmMsgScale_0001;
extern char *_XmMsgScale_0002;
extern char *_XmMsgScale_0005;
extern char *_XmMsgScale_0006;
extern char *_XmMsgScale_0007;
extern char *_XmMsgScale_0008;
extern char *_XmMsgScale_0009;
extern char *_XmMsgScreen_0000;
extern char *_XmMsgScreen_0001;
extern char *_XmMsgScrollBar_0000;
extern char *_XmMsgScrollBar_0001;
extern char *_XmMsgScrollBar_0002;
extern char *_XmMsgScrollBar_0003;
extern char *_XmMsgScrollBar_0004;
extern char *_XmMsgScrollBar_0005;
extern char *_XmMsgScrollBar_0006;
extern char *_XmMsgScrollBar_0007;
extern char *_XmMsgScrollBar_0008;
extern char *_XmMsgScrollFrameT_0000;
extern char *_XmMsgScrollFrameT_0001;
extern char *_XmMsgScrollVis_0000;
extern char *_XmMsgScrolledW_0004;
extern char *_XmMsgScrolledW_0005;
extern char *_XmMsgScrolledW_0006;
extern char *_XmMsgScrolledW_0007;
extern char *_XmMsgScrolledW_0008;
extern char *_XmMsgScrolledW_0009;
extern char *_XmMsgSelectioB_0001;
extern char *_XmMsgSelectioB_0002;
extern char *_XmMsgSpinB_0001;
extern char *_XmMsgSpinB_0002;
extern char *_XmMsgSpinB_0003;
extern char *_XmMsgSpinB_0004;
extern char *_XmMsgSpinB_0005;
extern char *_XmMsgSpinB_0006;
extern char *_XmMsgSpinB_0007;
extern char *_XmMsgTextFWcs_0000;
extern char *_XmMsgTextFWcs_0001;
extern char *_XmMsgTextF_0000;
extern char *_XmMsgTextF_0001;
extern char *_XmMsgTextF_0002;
extern char *_XmMsgTextF_0003;
extern char *_XmMsgTextF_0004;
extern char *_XmMsgTextF_0005;
extern char *_XmMsgTextF_0006;
extern char *_XmMsgTextIn_0000;
extern char *_XmMsgTextOut_0000;
extern char *_XmMsgText_0000;
extern char *_XmMsgText_0002;
extern char *_XmMsgTransfer_0000;
extern char *_XmMsgTransfer_0001;
extern char *_XmMsgTransfer_0002;
extern char *_XmMsgTransfer_0003;
extern char *_XmMsgTransfer_0004;
extern char *_XmMsgTransfer_0005;
extern char *_XmMsgTransfer_0006;
extern char *_XmMsgTransfer_0007;
extern char *_XmMsgVaSimple_0000;
extern char *_XmMsgVaSimple_0001;
extern char *_XmMsgVaSimple_0002;
extern char *_XmMsgVendorE_0000;
extern char *_XmMsgVendorE_0005;
extern char *_XmMsgVendor_0000;
extern char *_XmMsgVendor_0001;
extern char *_XmMsgVendor_0002;
extern char *_XmMsgVendor_0003;
extern char *_XmMsgVisual_0000;
extern char *_XmMsgVisual_0001;
extern char *_XmMsgVisual_0002;
extern char *_XmMsgXmIm_0000;
extern char *_XmMsgXmRenderT_0000; 
extern char *_XmMsgXmRenderT_0001;
extern char *_XmMsgXmRenderT_0002;
extern char *_XmMsgXmRenderT_0003;
extern char *_XmMsgXmRenderT_0004;
extern char *_XmMsgXmRenderT_0005;
extern char *_XmMsgXmSelect_0000;
extern char *_XmMsgXmSelect_0001;
extern char *_XmMsgXmSelect_0002;
extern char *_XmMsgXmString_0000;
extern char *_XmMsgXmTabList_0000;

struct {
	char	*n;
	char	**t;
} list[] = {
	{ "XME_WARNING", &XME_WARNING },
	{ "_XmMsgBaseClass_0000", &_XmMsgBaseClass_0000 },
	{ "_XmMsgBaseClass_0001", &_XmMsgBaseClass_0001 },
	{ "_XmMsgBaseClass_0002", &_XmMsgBaseClass_0002 },
	{ "_XmMsgBulletinB_0001", &_XmMsgBulletinB_0001 },
	{ "_XmMsgCSText_0000", &_XmMsgCSText_0000 },
	{ "_XmMsgCSText_0001", &_XmMsgCSText_0001 },
	{ "_XmMsgCSText_0002", &_XmMsgCSText_0002 },
	{ "_XmMsgCSText_0003", &_XmMsgCSText_0003 },
	{ "_XmMsgCSText_0004", &_XmMsgCSText_0004 },
	{ "_XmMsgCSText_0005", &_XmMsgCSText_0005 },
	{ "_XmMsgCSText_0006", &_XmMsgCSText_0006 },
	{ "_XmMsgCSText_0007", &_XmMsgCSText_0007 },
	{ "_XmMsgCascadeB_0000", &_XmMsgCascadeB_0000 },
	{ "_XmMsgCascadeB_0001", &_XmMsgCascadeB_0001 },
	{ "_XmMsgCascadeB_0002", &_XmMsgCascadeB_0002 },
	{ "_XmMsgCascadeB_0003", &_XmMsgCascadeB_0003 },
	{ "_XmMsgComboBox_0000", &_XmMsgComboBox_0000 },
	{ "_XmMsgComboBox_0001", &_XmMsgComboBox_0001 },
	{ "_XmMsgComboBox_0002", &_XmMsgComboBox_0002 },
	{ "_XmMsgComboBox_0003", &_XmMsgComboBox_0003 },
	{ "_XmMsgComboBox_0004", &_XmMsgComboBox_0004 },
	{ "_XmMsgComboBox_0005", &_XmMsgComboBox_0005 },
	{ "_XmMsgComboBox_0006", &_XmMsgComboBox_0006 },
	{ "_XmMsgComboBox_0007", &_XmMsgComboBox_0007 },
	{ "_XmMsgComboBox_0008", &_XmMsgComboBox_0008 },
	{ "_XmMsgCommand_0000", &_XmMsgCommand_0000 },
	{ "_XmMsgCommand_0001", &_XmMsgCommand_0001 },
	{ "_XmMsgCommand_0002", &_XmMsgCommand_0002 },
	{ "_XmMsgCommand_0003", &_XmMsgCommand_0003 },
	{ "_XmMsgCommand_0004", &_XmMsgCommand_0004 },
	{ "_XmMsgCommand_0005", &_XmMsgCommand_0005 },
	{ "_XmMsgContainer_0000", &_XmMsgContainer_0000 },
	{ "_XmMsgCutPaste_0000", &_XmMsgCutPaste_0000 },
	{ "_XmMsgCutPaste_0001", &_XmMsgCutPaste_0001 },
	{ "_XmMsgCutPaste_0002", &_XmMsgCutPaste_0002 },
	{ "_XmMsgCutPaste_0003", &_XmMsgCutPaste_0003 },
	{ "_XmMsgCutPaste_0004", &_XmMsgCutPaste_0004 },
	{ "_XmMsgCutPaste_0005", &_XmMsgCutPaste_0005 },
	{ "_XmMsgCutPaste_0006", &_XmMsgCutPaste_0006 },
	{ "_XmMsgCutPaste_0007", &_XmMsgCutPaste_0007 },
	{ "_XmMsgCutPaste_0008", &_XmMsgCutPaste_0008 },
	{ "_XmMsgCutPaste_0009", &_XmMsgCutPaste_0009 },
	{ "_XmMsgDialogS_0000", &_XmMsgDialogS_0000 },
	{ "_XmMsgDisplay_0001", &_XmMsgDisplay_0001 },
	{ "_XmMsgDisplay_0002", &_XmMsgDisplay_0002 },
	{ "_XmMsgDisplay_0003", &_XmMsgDisplay_0003 },
	{ "_XmMsgDragBS_0000", &_XmMsgDragBS_0000 },
	{ "_XmMsgDragBS_0001", &_XmMsgDragBS_0001 },
	{ "_XmMsgDragBS_0002", &_XmMsgDragBS_0002 },
	{ "_XmMsgDragBS_0003", &_XmMsgDragBS_0003 },
	{ "_XmMsgDragBS_0004", &_XmMsgDragBS_0004 },
	{ "_XmMsgDragBS_0005", &_XmMsgDragBS_0005 },
	{ "_XmMsgDragBS_0006", &_XmMsgDragBS_0006 },
	{ "_XmMsgDragC_0001", &_XmMsgDragC_0001 },
	{ "_XmMsgDragC_0002", &_XmMsgDragC_0002 },
	{ "_XmMsgDragC_0003", &_XmMsgDragC_0003 },
	{ "_XmMsgDragC_0004", &_XmMsgDragC_0004 },
	{ "_XmMsgDragC_0005", &_XmMsgDragC_0005 },
	{ "_XmMsgDragC_0006", &_XmMsgDragC_0006 },
	{ "_XmMsgDragICC_0000", &_XmMsgDragICC_0000 },
	{ "_XmMsgDragICC_0001", &_XmMsgDragICC_0001 },
	{ "_XmMsgDragIcon_0000", &_XmMsgDragIcon_0000 },
	{ "_XmMsgDragIcon_0001", &_XmMsgDragIcon_0001 },
	{ "_XmMsgDragIcon_0002", &_XmMsgDragIcon_0002 },
	{ "_XmMsgDragOverS_0000", &_XmMsgDragOverS_0000 },
	{ "_XmMsgDragOverS_0001", &_XmMsgDragOverS_0001 },
	{ "_XmMsgDragOverS_0002", &_XmMsgDragOverS_0002 },
	{ "_XmMsgDragOverS_0003", &_XmMsgDragOverS_0003 },
	{ "_XmMsgDragUnder_0000", &_XmMsgDragUnder_0000 },
	{ "_XmMsgDragUnder_0001", &_XmMsgDragUnder_0001 },
	{ "_XmMsgDropSMgrI_0001", &_XmMsgDropSMgrI_0001 },
	{ "_XmMsgDropSMgrI_0002", &_XmMsgDropSMgrI_0002 },
	{ "_XmMsgDropSMgrI_0003", &_XmMsgDropSMgrI_0003 },
	{ "_XmMsgDropSMgr_0001", &_XmMsgDropSMgr_0001 },
	{ "_XmMsgDropSMgr_0002", &_XmMsgDropSMgr_0002 },
	{ "_XmMsgDropSMgr_0003", &_XmMsgDropSMgr_0003 },
	{ "_XmMsgDropSMgr_0004", &_XmMsgDropSMgr_0004 },
	{ "_XmMsgDropSMgr_0005", &_XmMsgDropSMgr_0005 },
	{ "_XmMsgDropSMgr_0006", &_XmMsgDropSMgr_0006 },
	{ "_XmMsgDropSMgr_0007", &_XmMsgDropSMgr_0007 },
	{ "_XmMsgDropSMgr_0008", &_XmMsgDropSMgr_0008 },
	{ "_XmMsgDropSMgr_0009", &_XmMsgDropSMgr_0009 },
	{ "_XmMsgDropSMgr_0010", &_XmMsgDropSMgr_0010 },
	{ "_XmMsgForm_0000", &_XmMsgForm_0000 },
	{ "_XmMsgForm_0002", &_XmMsgForm_0002 },
	{ "_XmMsgForm_0003", &_XmMsgForm_0003 },
	{ "_XmMsgForm_0004", &_XmMsgForm_0004 },
	{ "_XmMsgGadget_0000", &_XmMsgGadget_0000 },
	{ "_XmMsgGeoUtils_0000", &_XmMsgGeoUtils_0000 },
	{ "_XmMsgGeoUtils_0001", &_XmMsgGeoUtils_0001 },
	{ "_XmMsgGeoUtils_0002", &_XmMsgGeoUtils_0002 },
	{ "_XmMsgGetSecRes_0000", &_XmMsgGetSecRes_0000 },
	{ "_XmMsgGrabS_0000", &_XmMsgGrabS_0000 },
	{ "_XmMsgLabel_0003", &_XmMsgLabel_0003 },
	{ "_XmMsgLabel_0004", &_XmMsgLabel_0004 },
	{ "_XmMsgList_0000", &_XmMsgList_0000 },
	{ "_XmMsgList_0005", &_XmMsgList_0005 },
	{ "_XmMsgList_0006", &_XmMsgList_0006 },
	{ "_XmMsgList_0007", &_XmMsgList_0007 },
	{ "_XmMsgList_0008", &_XmMsgList_0008 },
	{ "_XmMsgList_0009", &_XmMsgList_0009 },
	{ "_XmMsgList_0010", &_XmMsgList_0010 },
	{ "_XmMsgList_0011", &_XmMsgList_0011 },
	{ "_XmMsgList_0012", &_XmMsgList_0012 },
	{ "_XmMsgList_0013", &_XmMsgList_0013 },
	{ "_XmMsgList_0014", &_XmMsgList_0014 },
	{ "_XmMsgList_0015", &_XmMsgList_0015 },
	{ "_XmMsgMainW_0000", &_XmMsgMainW_0000 },
	{ "_XmMsgMainW_0001", &_XmMsgMainW_0001 },
	{ "_XmMsgManager_0000", &_XmMsgManager_0000 },
	{ "_XmMsgManager_0001", &_XmMsgManager_0001 },
	{ "_XmMsgMenuShell_0000", &_XmMsgMenuShell_0000 },
	{ "_XmMsgMenuShell_0001", &_XmMsgMenuShell_0001 },
	{ "_XmMsgMenuShell_0002", &_XmMsgMenuShell_0002 },
	{ "_XmMsgMenuShell_0003", &_XmMsgMenuShell_0003 },
	{ "_XmMsgMenuShell_0004", &_XmMsgMenuShell_0004 },
	{ "_XmMsgMenuShell_0005", &_XmMsgMenuShell_0005 },
	{ "_XmMsgMenuShell_0006", &_XmMsgMenuShell_0006 },
	{ "_XmMsgMenuShell_0007", &_XmMsgMenuShell_0007 },
	{ "_XmMsgMenuShell_0008", &_XmMsgMenuShell_0008 },
	{ "_XmMsgMenuShell_0009", &_XmMsgMenuShell_0009 },
	{ "_XmMsgMessageB_0003", &_XmMsgMessageB_0003 },
	{ "_XmMsgMessageB_0004", &_XmMsgMessageB_0004 },
	{ "_XmMsgMotif_0000", &_XmMsgMotif_0000 },
	{ "_XmMsgMotif_0001", &_XmMsgMotif_0001 },
	{ "_XmMsgNavigMap_0000", &_XmMsgNavigMap_0000 },
	{ "_XmMsgNotebook_0000", &_XmMsgNotebook_0000 },
	{ "_XmMsgPanedW_0000", &_XmMsgPanedW_0000 },
	{ "_XmMsgPanedW_0001", &_XmMsgPanedW_0001 },
	{ "_XmMsgPanedW_0002", &_XmMsgPanedW_0002 },
	{ "_XmMsgPanedW_0003", &_XmMsgPanedW_0003 },
	{ "_XmMsgPanedW_0004", &_XmMsgPanedW_0004 },
	{ "_XmMsgPanedW_0005", &_XmMsgPanedW_0005 },
	{ "_XmMsgPixConv_0000", &_XmMsgPixConv_0000 },
	{ "_XmMsgPrimitive_0000", &_XmMsgPrimitive_0000 },
	{ "_XmMsgProtocols_0000", &_XmMsgProtocols_0000 },
	{ "_XmMsgProtocols_0001", &_XmMsgProtocols_0001 },
	{ "_XmMsgProtocols_0002", &_XmMsgProtocols_0002 },
	{ "_XmMsgRegion_0000", &_XmMsgRegion_0000 },
	{ "_XmMsgRepType_0001", &_XmMsgRepType_0001 },
	{ "_XmMsgRepType_0002", &_XmMsgRepType_0002 },
	{ "_XmMsgResConvert_0000", &_XmMsgResConvert_0000 },
	{ "_XmMsgResConvert_0001", &_XmMsgResConvert_0001 },
	{ "_XmMsgResConvert_0002", &_XmMsgResConvert_0002 },
	{ "_XmMsgResConvert_0003", &_XmMsgResConvert_0003 },
	{ "_XmMsgResConvert_0004", &_XmMsgResConvert_0004 },
	{ "_XmMsgResConvert_0005", &_XmMsgResConvert_0005 },
	{ "_XmMsgResConvert_0006", &_XmMsgResConvert_0006 },
	{ "_XmMsgResConvert_0007", &_XmMsgResConvert_0007 },
	{ "_XmMsgResConvert_0008", &_XmMsgResConvert_0008 },
	{ "_XmMsgResConvert_0009", &_XmMsgResConvert_0009 },
	{ "_XmMsgResConvert_0010", &_XmMsgResConvert_0010 },
	{ "_XmMsgResConvert_0011", &_XmMsgResConvert_0011 },
	{ "_XmMsgResConvert_0012", &_XmMsgResConvert_0012 },
	{ "_XmMsgResConvert_0013", &_XmMsgResConvert_0013 },
	{ "_XmMsgResConvert_0014", &_XmMsgResConvert_0014 },
	{ "_XmMsgResConvert_0015", &_XmMsgResConvert_0015 },
	{ "_XmMsgResConvert_0016", &_XmMsgResConvert_0016 },
	{ "_XmMsgRowColText_0024", &_XmMsgRowColText_0024 },
	{ "_XmMsgRowColumn_0000", &_XmMsgRowColumn_0000 },
	{ "_XmMsgRowColumn_0001", &_XmMsgRowColumn_0001 },
	{ "_XmMsgRowColumn_0002", &_XmMsgRowColumn_0002 },
	{ "_XmMsgRowColumn_0003", &_XmMsgRowColumn_0003 },
	{ "_XmMsgRowColumn_0004", &_XmMsgRowColumn_0004 },
	{ "_XmMsgRowColumn_0005", &_XmMsgRowColumn_0005 },
	{ "_XmMsgRowColumn_0007", &_XmMsgRowColumn_0007 },
	{ "_XmMsgRowColumn_0008", &_XmMsgRowColumn_0008 },
	{ "_XmMsgRowColumn_0015", &_XmMsgRowColumn_0015 },
	{ "_XmMsgRowColumn_0016", &_XmMsgRowColumn_0016 },
	{ "_XmMsgRowColumn_0017", &_XmMsgRowColumn_0017 },
	{ "_XmMsgRowColumn_0018", &_XmMsgRowColumn_0018 },
	{ "_XmMsgRowColumn_0019", &_XmMsgRowColumn_0019 },
	{ "_XmMsgRowColumn_0020", &_XmMsgRowColumn_0020 },
	{ "_XmMsgRowColumn_0022", &_XmMsgRowColumn_0022 },
	{ "_XmMsgRowColumn_0023", &_XmMsgRowColumn_0023 },
	{ "_XmMsgRowColumn_0025", &_XmMsgRowColumn_0025 },
	{ "_XmMsgRowColumn_0026", &_XmMsgRowColumn_0026 },
	{ "_XmMsgRowColumn_0027", &_XmMsgRowColumn_0027 },
	{ "_XmMsgScaleScrBar_0004", &_XmMsgScaleScrBar_0004 },
	{ "_XmMsgScale_0000", &_XmMsgScale_0000 },
	{ "_XmMsgScale_0001", &_XmMsgScale_0001 },
	{ "_XmMsgScale_0002", &_XmMsgScale_0002 },
	{ "_XmMsgScale_0005", &_XmMsgScale_0005 },
	{ "_XmMsgScale_0006", &_XmMsgScale_0006 },
	{ "_XmMsgScale_0007", &_XmMsgScale_0007 },
	{ "_XmMsgScale_0008", &_XmMsgScale_0008 },
	{ "_XmMsgScale_0009", &_XmMsgScale_0009 },
	{ "_XmMsgScreen_0000", &_XmMsgScreen_0000 },
	{ "_XmMsgScreen_0001", &_XmMsgScreen_0001 },
	{ "_XmMsgScrollBar_0000", &_XmMsgScrollBar_0000 },
	{ "_XmMsgScrollBar_0001", &_XmMsgScrollBar_0001 },
	{ "_XmMsgScrollBar_0002", &_XmMsgScrollBar_0002 },
	{ "_XmMsgScrollBar_0003", &_XmMsgScrollBar_0003 },
	{ "_XmMsgScrollBar_0004", &_XmMsgScrollBar_0004 },
	{ "_XmMsgScrollBar_0005", &_XmMsgScrollBar_0005 },
	{ "_XmMsgScrollBar_0006", &_XmMsgScrollBar_0006 },
	{ "_XmMsgScrollBar_0007", &_XmMsgScrollBar_0007 },
	{ "_XmMsgScrollBar_0008", &_XmMsgScrollBar_0008 },
	{ "_XmMsgScrollFrameT_0000", &_XmMsgScrollFrameT_0000 },
	{ "_XmMsgScrollFrameT_0001", &_XmMsgScrollFrameT_0001 },
	{ "_XmMsgScrollVis_0000", &_XmMsgScrollVis_0000 },
	{ "_XmMsgScrolledW_0004", &_XmMsgScrolledW_0004 },
	{ "_XmMsgScrolledW_0005", &_XmMsgScrolledW_0005 },
	{ "_XmMsgScrolledW_0006", &_XmMsgScrolledW_0006 },
	{ "_XmMsgScrolledW_0007", &_XmMsgScrolledW_0007 },
	{ "_XmMsgScrolledW_0008", &_XmMsgScrolledW_0008 },
	{ "_XmMsgScrolledW_0009", &_XmMsgScrolledW_0009 },
	{ "_XmMsgSelectioB_0001", &_XmMsgSelectioB_0001 },
	{ "_XmMsgSelectioB_0002", &_XmMsgSelectioB_0002 },
	{ "_XmMsgSpinB_0001", &_XmMsgSpinB_0001 },
	{ "_XmMsgSpinB_0002", &_XmMsgSpinB_0002 },
	{ "_XmMsgSpinB_0003", &_XmMsgSpinB_0003 },
	{ "_XmMsgSpinB_0004", &_XmMsgSpinB_0004 },
	{ "_XmMsgSpinB_0005", &_XmMsgSpinB_0005 },
	{ "_XmMsgSpinB_0006", &_XmMsgSpinB_0006 },
	{ "_XmMsgSpinB_0007", &_XmMsgSpinB_0007 },
	{ "_XmMsgTextFWcs_0000", &_XmMsgTextFWcs_0000 },
	{ "_XmMsgTextFWcs_0001", &_XmMsgTextFWcs_0001 },
	{ "_XmMsgTextF_0000", &_XmMsgTextF_0000 },
	{ "_XmMsgTextF_0001", &_XmMsgTextF_0001 },
	{ "_XmMsgTextF_0002", &_XmMsgTextF_0002 },
	{ "_XmMsgTextF_0003", &_XmMsgTextF_0003 },
	{ "_XmMsgTextF_0004", &_XmMsgTextF_0004 },
	{ "_XmMsgTextF_0005", &_XmMsgTextF_0005 },
	{ "_XmMsgTextF_0006", &_XmMsgTextF_0006 },
	{ "_XmMsgTextIn_0000", &_XmMsgTextIn_0000 },
	{ "_XmMsgTextOut_0000", &_XmMsgTextOut_0000 },
	{ "_XmMsgText_0000", &_XmMsgText_0000 },
	{ "_XmMsgText_0002", &_XmMsgText_0002 },
	{ "_XmMsgTransfer_0000", &_XmMsgTransfer_0000 },
	{ "_XmMsgTransfer_0001", &_XmMsgTransfer_0001 },
	{ "_XmMsgTransfer_0002", &_XmMsgTransfer_0002 },
	{ "_XmMsgTransfer_0003", &_XmMsgTransfer_0003 },
	{ "_XmMsgTransfer_0004", &_XmMsgTransfer_0004 },
	{ "_XmMsgTransfer_0005", &_XmMsgTransfer_0005 },
	{ "_XmMsgTransfer_0006", &_XmMsgTransfer_0006 },
	{ "_XmMsgTransfer_0007", &_XmMsgTransfer_0007 },
	{ "_XmMsgVaSimple_0000", &_XmMsgVaSimple_0000 },
	{ "_XmMsgVaSimple_0001", &_XmMsgVaSimple_0001 },
	{ "_XmMsgVaSimple_0002", &_XmMsgVaSimple_0002 },
	{ "_XmMsgVendorE_0000", &_XmMsgVendorE_0000 },
	{ "_XmMsgVendorE_0005", &_XmMsgVendorE_0005 },
	{ "_XmMsgVendor_0000", &_XmMsgVendor_0000 },
	{ "_XmMsgVendor_0001", &_XmMsgVendor_0001 },
	{ "_XmMsgVendor_0002", &_XmMsgVendor_0002 },
	{ "_XmMsgVendor_0003", &_XmMsgVendor_0003 },
	{ "_XmMsgVisual_0000", &_XmMsgVisual_0000 },
	{ "_XmMsgVisual_0001", &_XmMsgVisual_0001 },
	{ "_XmMsgVisual_0002", &_XmMsgVisual_0002 },
	{ "_XmMsgXmIm_0000", &_XmMsgXmIm_0000 },
	{ "_XmMsgXmRenderT_0000", &_XmMsgXmRenderT_0000 },
	{ "_XmMsgXmRenderT_0001", &_XmMsgXmRenderT_0001 },
	{ "_XmMsgXmRenderT_0002", &_XmMsgXmRenderT_0002 },
	{ "_XmMsgXmRenderT_0003", &_XmMsgXmRenderT_0003 },
	{ "_XmMsgXmRenderT_0004", &_XmMsgXmRenderT_0004 },
	{ "_XmMsgXmRenderT_0005", &_XmMsgXmRenderT_0005 },
	{ "_XmMsgXmSelect_0000", &_XmMsgXmSelect_0000 },
	{ "_XmMsgXmSelect_0001", &_XmMsgXmSelect_0001 },
	{ "_XmMsgXmSelect_0002", &_XmMsgXmSelect_0002 },
	{ "_XmMsgXmString_0000", &_XmMsgXmString_0000 },
	{ "_XmMsgXmTabList_0000", &_XmMsgXmTabList_0000 },
	{ NULL, NULL }
};

char *copyright = 
"/**\n"
" *\n"
" * Copyright (C) 1997 Peter G. Williams, and Others\n"
" *\n"
" * This file is part of the GNU LessTif Library.\n"
" *\n"
" * This library is free software; you can redistribute it and/or\n"
" * modify it under the terms of the GNU Library General Public\n"
" * License as published by the Free Software Foundation; either\n"
" * version 2 of the License, or (at your option) any later version.\n"
" *\n"
" * This library is distributed in the hope that it will be useful,\n"
" * but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
" * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
" * Library General Public License for more details.\n"
" *\n"
" * You should have received a copy of the GNU Library General Public\n"
" * License along with this library; if not, write to the Free\n"
" * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n"
" *\n"
" **/\n";

int
main(int argc, char *argv[])
{
	int	i;
	char	*p;

        printf(copyright);
	printf("\n");
	printf("\n");
        printf("#ifndef XM_MESSAGES_I_H\n");
        printf("#define XM_MESSAGES_I_H\n");
	printf("\n");
	printf("#ifdef __cplusplus\n");
	printf("extern \"C\" {\n");
	printf("#endif\n");
	printf("\n");
	for (i=0; list[i].n; i++) {
		printf("extern _XmConst char * %s;\n", list[i].n);
	}
	printf("\n");
	printf("#ifdef __cplusplus\n");
	printf("}\n");
	printf("#endif\n");
	printf("\n");
	printf("#endif /* XM_MESSAGES_I_H */\n");
	printf("\n");
	exit(0);
}

